@@ -1,15 +1,18 @@
-from six import text_type
-
 from .base import GraphQLError
 
 # Necessary for static type checking
 if False:  # flake8: noqa
-    from typing import Any, Dict, Union
+    from typing import Any, Dict
 
 
 def format_error(error):
     # type: (Exception) -> Dict[str, Any]
-    formatted_error = {"message": text_type(error)}  # type: Dict[str, Any]
+    # Protect against UnicodeEncodeError when run in py2 (#216)
+    try:
+        message = str(error)
+    except UnicodeEncodeError:
+        message = error.message.encode("utf-8")  # type: ignore
+    formatted_error = {"message": message}  # type: Dict[str, Any]
     if isinstance(error, GraphQLError):
         if error.locations is not None:
             formatted_error["locations"] = [
@@ -18,4 +21,7 @@ def format_error(error):
         if error.path is not None:
             formatted_error["path"] = error.path
 
+        if error.extensions is not None:
+            formatted_error["extensions"] = error.extensions
+
     return formatted_error
