@@ -59,9 +59,9 @@ def subscribe(*args, **kwargs):
 def execute(
     schema,  # type: GraphQLSchema
     document_ast,  # type: Document
-    root=None,  # type: Any
-    context=None,  # type: Optional[Any]
-    variables=None,  # type: Optional[Any]
+    root_value=None,  # type: Any
+    context_value=None,  # type: Optional[Any]
+    variable_values=None,  # type: Optional[Any]
     operation_name=None,  # type: Optional[str]
     executor=None,  # type: Any
     return_promise=False,  # type: bool
@@ -71,27 +71,27 @@ def execute(
 ):
     # type: (...) -> Union[ExecutionResult, Promise[ExecutionResult]]
 
-    if root is None and "root_value" in options:
+    if root_value is None and "root" in options:
         warnings.warn(
-            "root_value has been deprecated. Please use root=... instead.",
+            "The 'root' alias has been deprecated. Please use 'root_value' instead.",
             category=DeprecationWarning,
             stacklevel=2,
         )
-        root = options["root_value"]
-    if context is None and "context_value" in options:
+        root_value = options["root"]
+    if context_value is None and "context" in options:
         warnings.warn(
-            "context_value has been deprecated. Please use context=... instead.",
+            "The 'context' alias has been deprecated. Please use 'context_value' instead.",
             category=DeprecationWarning,
             stacklevel=2,
         )
-        context = options["context_value"]
-    if variables is None and "variable_values" in options:
+        context_value = options["context"]
+    if variable_values is None and "variables" in options:
         warnings.warn(
-            "variable_values has been deprecated. Please use variables=... instead.",
+            "The 'variables' alias has been deprecated. Please use 'variable_values' instead.",
             category=DeprecationWarning,
             stacklevel=2,
         )
-        variables = options["variable_values"]
+        variable_values = options["variables"]
     assert schema, "Must provide schema"
     assert isinstance(schema, GraphQLSchema), (
         "Schema must be an instance of GraphQLSchema. Also ensure that there are "
@@ -113,9 +113,9 @@ def execute(
     exe_context = ExecutionContext(
         schema,
         document_ast,
-        root,
-        context,
-        variables or {},
+        root_value,
+        context_value,
+        variable_values or {},
         operation_name,
         executor,
         middleware,
@@ -124,7 +124,7 @@ def execute(
 
     def promise_executor(v):
         # type: (Optional[Any]) -> Union[Dict, Promise[Dict], Observable]
-        return execute_operation(exe_context, exe_context.operation, root)
+        return execute_operation(exe_context, exe_context.operation, root_value)
 
     def on_rejected(error):
         # type: (Exception) -> None
@@ -267,6 +267,7 @@ def subscribe_fields(
     parent_type,  # type: GraphQLObjectType
     source_value,  # type: Any
     fields,  # type: DefaultOrderedDict
+    only_first_field=True,  # type: bool
 ):
     # type: (...) -> Observable
     subscriber_exe_context = SubscriberExecutionContext(exe_context)
@@ -283,9 +284,14 @@ def subscribe_fields(
         subscriber_exe_context.reset()
         return result
 
+    def catch_error(error):
+        subscriber_exe_context.errors.append(error)
+        return Observable.just(None)
+
     observables = []  # type: List[Observable]
 
-    # assert len(fields) == 1, "Can only subscribe one element at a time."
+    # TODO: Make sure this works with multiple fields (currently untested)
+    # so we can remove the "only_first_field" argument.
 
     for response_name, field_asts in fields.items():
         result = subscribe_field(
@@ -297,16 +303,12 @@ def subscribe_fields(
         )
         if result is Undefined:
             continue
-
-        def catch_error(error):
-            subscriber_exe_context.errors.append(error)
-            return Observable.just(None)
-
         # Map observable results
         observable = result.catch_exception(catch_error).map(
             lambda data: map_result({response_name: data})
         )
-        return observable
+        if only_first_field:
+            return observable
         observables.append(observable)
 
     return Observable.merge(observables)
@@ -529,8 +531,10 @@ def complete_value(
             lambda resolved: complete_value(
                 exe_context, return_type, field_asts, info, path, resolved
             ),
-            lambda error: Promise.rejected(
-                GraphQLLocatedError(field_asts, original_error=error, path=path)
+            lambda error: Promise.rejected(  # type: ignore
+                GraphQLLocatedError(  # type: ignore
+                    field_asts, original_error=error, path=path
+                )
             ),
         )
 
@@ -602,7 +606,11 @@ def complete_list_value(
         completed_results.append(completed_item)
         index += 1
 
-    return Promise.all(completed_results) if contains_promise else completed_results
+    return (
+        Promise.all(completed_results)  # type: ignore
+        if contains_promise
+        else completed_results
+    )
 
 
 def complete_leaf_value(
@@ -711,7 +719,9 @@ def complete_object_value(
 
     # Collect sub-fields to execute to complete this value.
     subfield_asts = exe_context.get_sub_fields(return_type, field_asts)
-    return execute_fields(exe_context, return_type, result, subfield_asts, path, info)
+    return execute_fields(  # type: ignore
+        exe_context, return_type, result, subfield_asts, path, info
+    )
 
 
 def complete_nonnull_value(
