@@ -404,6 +404,7 @@ class GraphQLInterfaceType(GraphQLNamedType):
     @cached_property
     def fields(self):
         # type: () -> Dict[str, GraphQLField]
+        assert self._fields is not None, '"fields" cannot be None'
         return define_field_map(self, self._fields)
 
 
@@ -551,7 +552,10 @@ class GraphQLEnumType(GraphQLNamedType):
     @cached_property
     def _value_lookup(self):
         # type: () -> Dict[str, GraphQLEnumValue]
-        return {value.value: value for value in self.values}
+        return {
+            value.value.value if isinstance(value.value, PyEnum) else value.value: value
+            for value in self.values
+        }
 
     @cached_property
     def _name_lookup(self):
@@ -645,7 +649,7 @@ class GraphQLInputObjectType(GraphQLNamedType):
         self.name = name
         self.description = description
         if container_type is None:
-            container_type = dict  # type: ignore
+            container_type = OrderedDict  # type: ignore
         assert callable(container_type), "container_type must be callable"
         self.container_type = container_type
         self._fields = fields
