@@ -35,7 +35,9 @@ def _test_schema(server_schema):
     initial_introspection = graphql(server_schema, introspection_query)
     client_schema = build_client_schema(initial_introspection.data)
     second_introspection = graphql(client_schema, introspection_query)
-    assert contain_subset(initial_introspection.data, second_introspection.data)
+    assert contain_subset(
+        initial_introspection.data, second_introspection.data
+    ), "\n{}\n{}".format(initial_introspection.data, second_introspection.data)
 
     return client_schema
 
@@ -475,7 +477,9 @@ def test_builds_a_schema_with_field_arguments_with_default_values():
                             args={
                                 "objArg": GraphQLArgument(
                                     GeoType,
-                                    default_value={"lat": 37.485, "lon": -122.148},
+                                    default_value=OrderedDict(
+                                        [("lat", 37.485), ("lon", -122.148)]
+                                    ),
                                 )
                             },
                         ),
@@ -709,7 +713,7 @@ def test_throws_when_missing_kind():
     )
 
 
-def test_succeds_on_smaller_equals_than_7_deep_lists():
+def test_succeeds_on_smaller_equals_than_7_deep_lists():
     schema = GraphQLSchema(
         query=GraphQLObjectType(
             name="Query",
